# Graphene JWT Auth

## Overview
This package provides [JSON Web Token Authentication](http://tools.ietf.org/html/draft-ietf-oauth-json-web-token) support for Django and Graphene.

Based on the :
* [Django JWT Auth](https://github.com/jpadilla/django-jwt-auth) package. (this project forked from this package)
* [REST framework JWT Auth](https://github.com/GetBlimp/django-rest-framework-jwt) package.
* [Django REST framework](https://github.com/tomchristie/django-rest-framework) package.

This package includes blacklist, long running token, middleware for django and graphene for auth with JWT token header, custom error handling.


## Warning
* Not tested yet.
* Document is not available yet.
* Still on development.
* My english is realllyyyy bad (still learning).
* Pull request is welcome.
